# eric7.Plugins.WizardPlugins.SetupWizard.SetupWizardDialog

Module implementing the setup.py wizard dialog.

### Global Attributes

None

### Classes

SetupWizardDialog | Class implementing the setup.py wizard dialog.

### Functions

None

## SetupWizardDialog

Class implementing the setup.py wizard dialog.

It displays a dialog for entering the parameters for the setup.py code generator.

### Derived from

QDialog, Ui_SetupWizardDialog

### Class Attributes

ClassifiersUrl

### Class Methods

None

### Methods

SetupWizardDialog | Constructor
__addClassifierEntry | Private method to add a new entry to the list of trove classifiers.
__classifiersDownloadDone | Private slot called, after the classifiers file has been downloaded from the internet.
__enableOkButton | Private slot to set the state of the OK button.
__getLicenseText | Private method to get the license text.
__getStartDir | Private method to get the start directory for selection dialogs.
__loadClassifiersFromPyPI | Private method to populate the classifiers list with data retrieved from PyPI.
__populateClassifiers | Private method to populate the classifiers.
getCode | Public method to get the source code.
on_addExludePatternButton_clicked | Private slot to add an exclude pattern to the list.
on_addModuleButton_clicked | Private slot to add Python modules to the list.
on_addScriptButton_clicked | Private slot to add scripts to the list.
on_deleteExcludePatternButton_clicked | Private slot to delete the selected exclude pattern items.
on_deleteModuleButton_clicked | Private slot to delete the selected script items.
on_deleteScriptButton_clicked | Private slot to delete the selected script items.
on_excludePatternEdit_returnPressed | Private slot handling a press of the return button of the exclude pattern edit.
on_excludePatternEdit_textChanged | Private slot to handle a change of the exclude pattern text.
on_excludePatternList_itemSelectionChanged | Private slot to handle a change of selected items of the exclude pattern list.
on_localClassifiersButton_clicked | Private method to populate lists from the Trove list file.
on_modulesList_itemSelectionChanged | Private slot to handle a change of selected items of the modules list.
on_projectButton_clicked | Private slot to populate some fields with data retrieved from the current project.
on_scriptsList_itemSelectionChanged | Private slot to handle a change of selected items of the scripts list.

### Static Methods

None

#### SetupWizardDialog (Constructor)

SetupWizardDialog(parent=None)

Constructor

parent
  reference to the parent widget (QWidget)

#### SetupWizardDialog.__addClassifierEntry

__addClassifierEntry(line)

Private method to add a new entry to the list of trove classifiers.

line
  line containing the data for the entry (string)

#### SetupWizardDialog.__classifiersDownloadDone

__classifiersDownloadDone(reply)

Private slot called, after the classifiers file has been downloaded from the internet.

reply (QNetworkReply)
  reference to the network reply

#### SetupWizardDialog.__enableOkButton

__enableOkButton()

Private slot to set the state of the OK button.

#### SetupWizardDialog.__getLicenseText

__getLicenseText()

Private method to get the license text.

Return:
  license text (string)

#### SetupWizardDialog.__getStartDir

__getStartDir()

Private method to get the start directory for selection dialogs.

Return:
  start directory (string)

#### SetupWizardDialog.__loadClassifiersFromPyPI

__loadClassifiersFromPyPI()

Private method to populate the classifiers list with data retrieved from PyPI.

#### SetupWizardDialog.__populateClassifiers

__populateClassifiers(classifiers)

Private method to populate the classifiers.

classifiers (list of str)
  list of classifiers read from a local file or retrieved from PyPI

#### SetupWizardDialog.getCode

getCode(indLevel, indString)

Public method to get the source code.

indLevel
  indentation level (int)
indString
  string used for indentation (space or tab) (string)

Return:
  generated code (string)

#### SetupWizardDialog.on_addExludePatternButton_clicked

on_addExludePatternButton_clicked()

Private slot to add an exclude pattern to the list.

#### SetupWizardDialog.on_addModuleButton_clicked

on_addModuleButton_clicked()

Private slot to add Python modules to the list.

#### SetupWizardDialog.on_addScriptButton_clicked

on_addScriptButton_clicked()

Private slot to add scripts to the list.

#### SetupWizardDialog.on_deleteExcludePatternButton_clicked

on_deleteExcludePatternButton_clicked()

Private slot to delete the selected exclude pattern items.

#### SetupWizardDialog.on_deleteModuleButton_clicked

on_deleteModuleButton_clicked()

Private slot to delete the selected script items.

#### SetupWizardDialog.on_deleteScriptButton_clicked

on_deleteScriptButton_clicked()

Private slot to delete the selected script items.

#### SetupWizardDialog.on_excludePatternEdit_returnPressed

on_excludePatternEdit_returnPressed()

Private slot handling a press of the return button of the exclude pattern edit.

#### SetupWizardDialog.on_excludePatternEdit_textChanged

on_excludePatternEdit_textChanged(txt)

Private slot to handle a change of the exclude pattern text.

txt
  text of the line edit (string)

#### SetupWizardDialog.on_excludePatternList_itemSelectionChanged

on_excludePatternList_itemSelectionChanged()

Private slot to handle a change of selected items of the exclude pattern list.

#### SetupWizardDialog.on_localClassifiersButton_clicked

on_localClassifiersButton_clicked()

Private method to populate lists from the Trove list file.

Note: The trove list file was created from querying "https://pypi.org/pypi?%3Aaction=list_classifiers".

#### SetupWizardDialog.on_modulesList_itemSelectionChanged

on_modulesList_itemSelectionChanged()

Private slot to handle a change of selected items of the modules list.

#### SetupWizardDialog.on_projectButton_clicked

on_projectButton_clicked()

Private slot to populate some fields with data retrieved from the current project.

#### SetupWizardDialog.on_scriptsList_itemSelectionChanged

on_scriptsList_itemSelectionChanged()

Private slot to handle a change of selected items of the scripts list.

Up